#!/usr/bin/env ruby

# Copyright (C) 2016 Open Source Robotics Foundation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'open3'
require 'pathname'

COMMANDS = {
  'msg' => '../../../libexec/gz/msgs11//gz-msgs'
}.freeze

# Class for the Gazebo msgs command line tools.
#
class Cmd
  def execute(args)
    exe_name = COMMANDS[args[0]]

    unless Pathname.new(exe_name).absolute?
      # We're assuming that the library path is relative to the current
      # location of this script.
      exe_name = File.expand_path(File.join(File.dirname(__FILE__), LIBRARY_NAME))
    end

    # Drop command from list of arguments
    Open3.popen2e(exe_name, *args[1..1]) do |_in, out_err, wait_thr|
      begin
        out_err.each do |line|
          print line
        end
        exit(wait_thr.value.exitstatus)
      rescue Interrupt => e
        print e.message
        exit(-1)
      end
    end
  end
end
